==> core-react-0.8.0.tgz: package/es/Form/Form/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import update from 'react-update';
import cx from 'classnames';
import invariant from 'invariant';
import xhr from '../../_utils/xhr';


var Form = /*#__PURE__*/function (_React$Component) {
  _inherits(Form, _React$Component);

  function Form(props) {
    var _this;

    _classCallCheck(this, Form);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Form).call(this)); // 存储 FormItem 实例，用于访问 FormItem

    _defineProperty(_assertThisInitialized(_this), "handleSubmit", function () {
      // e.preventDefault()
      _this.props.onSubmit && _this.validate() && _this.props.onSubmit(_this.state.data);
    });

    _this.items = [];
    _this.state = {
      data: props.data || props.defaultData || {},
      isReload: true
    };
    return _this;
  }

  _createClass(Form, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        form: this
      };
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref) {
      var data = _ref.data;
      data && this.setState({
        data: data
      });
    }
    /**
     * 初始化表单数据重新挂载表单内模块
     * @param data
     */

  }, {
    key: "init",
    value: function init(data) {
      this.setState({
        data: data || {},
        isReload: false
      });
      this.setState({
        isReload: true
      });
    }
  }, {
    key: "getItemValue",
    value: function getItemValue(instance, props) {
      var _ref2 = props || instance.props,
          name = _ref2.name,
          multiple = _ref2.multiple;

      var value = this.state.data[name];

      if (!multiple) {
        return value;
      } else {
        if (value instanceof Array) {
          return value[this.multipleMap[instance.uuid]];
        }

        return null;
      }
    }
  }, {
    key: "setItemValue",
    value: function setItemValue(instance, value) {
      var _instance$props = instance.props,
          name = _instance$props.name,
          multiple = _instance$props.multiple;
      var data = this.state.data;
      var nextData;

      if (!multiple) {
        nextData = update(data, 'set', name, value);
      } else {
        if (!data[name]) {
          data[name] = [];
        }

        nextData = update(data, 'set', [name, this.multipleMap[instance.uuid]], value);
      }

      this.setState({
        data: nextData
      });
      this.props.onChange && this.props.onChange(nextData);
    }
  }, {
    key: "addItem",
    value: function addItem(newItem) {
      if (newItem.props.multiple) {
        newItem.uuid = Math.random().toString(16).slice(2);
        this.multipleMap || (this.multipleMap = {});
        this.multipleMap[newItem.uuid] = this.items.filter(function (item) {
          return item.props.name === newItem.props.name;
        }).length;
      }

      this.items.push(newItem);
    }
  }, {
    key: "removeItem",
    value: function removeItem(item) {
      var _this2 = this;

      if (item.props.multiple) {
        delete this.multipleMap[item.uuid]; // Reset index

        var name = item.props.name;
        this.items.filter(function (item) {
          return item.props.name === name;
        }).forEach(function (item, i) {
          _this2.multipleMap[item.uuid] = i;
        });
      }

      this.items.splice(this.items.indexOf(item), 1);
    }
    /**
     * @public
     * @name this.refs.form.validate
     * @param  {object} [data] 验证的数据，默认验证表单当前的数据
     * @return {boolean} 成功/失败
     * @description 表单整体验证
     */

  }, {
    key: "validate",
    value: function validate(data) {
      var _this3 = this;

      data || (data = this.state.data);
      var isValid = true;
      this.items.forEach(function (formItem) {
        var _formItem$props = formItem.props,
            name = _formItem$props.name,
            multiple = _formItem$props.multiple;

        if (!multiple) {
          formItem.validate(data[name]) || (isValid = false);
        } else {
          var index = _this3.multipleMap[formItem.uuid];
          formItem.validate(data[name] && data[name][index]) || (isValid = false);
        }
      });
      return isValid;
    }
    /**
     * @public
     * @name this.refs.form.save
     * @param  {object} [data] 提交的数据，默认提交表单当前的数据
     * @description 表单提交，提交地址为 action 属性, 默认提交 data
     * 属性数据，可以自定义传入。发送请求前会进行表单验证, 提交成功会响应 onSuccess
     */

  }, {
    key: "save",
    value: function save() {
      var _this4 = this;

      var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.state.data;
      var _this$props = this.props,
          action = _this$props.action,
          sendDataFormatter = _this$props.sendDataFormatter,
          onSuccess = _this$props.onSuccess;

      if (this.validate()) {
        invariant(action, 'No `action` provided, check the Form component you save.');
        this.submit && this.submit.toggleProcess(true);
        xhr({
          type: 'POST',
          url: action,
          data: sendDataFormatter ? sendDataFormatter(data) : data,
          success: function success(data) {
            onSuccess && onSuccess(data);
          },
          complete: function complete() {
            _this4.submit && _this4.submit.toggleProcess(false);
          }
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          data = _this$props2.data,
          defaultData = _this$props2.defaultData,
          onChange = _this$props2.onChange,
          onSubmit = _this$props2.onSubmit,
          onSuccess = _this$props2.onSuccess,
          size = _this$props2.size,
          rules = _this$props2.rules,
          labelWidth = _this$props2.labelWidth,
          width = _this$props2.width,
          other = _objectWithoutProperties(_this$props2, ["children", "className", "data", "defaultData", "onChange", "onSubmit", "onSuccess", "size", "rules", "labelWidth", "width"]);

      var classNames = cx("".concat("waui", "-form"), _defineProperty({}, "".concat("waui", "-form_").concat(size), size));

      if (width) {
        other.style = Object.assign(other.style || {}, {
          width: width
        });
      }

      return React.createElement("form", _extends({
        onSubmit: this.handleSubmit,
        className: classNames
      }, other), this.state.isReload && children);
    }
  }]);

  return Form;
}(React.Component);

Form.childContextTypes = {
  form: PropTypes.instanceOf(Form)
};
Form.defaultProps = {
  labelWidth: 100
};
Form.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  // 表单数据源，作为表单验证时的数据对象，即 FormInput、FormSelect、FormTextarea 等自动填充的数据源
  data: PropTypes.object,
  // 表单数据源（不可控），同 data
  defaultData: PropTypes.object,
  // 表单数据改变后的回调，参数为当前表单的数据
  onChange: PropTypes.func,
  // 表单验证规则，需要验证的 key 与 data 对象一一对应
  rules: PropTypes.object,
  // 表单的宽度大小，单位为px
  width: PropTypes.number,
  // 表单 label 宽度，如果不需要 label，设置为`0`即可
  labelWidth: PropTypes.number,
  // 表单提交 URL，内部调用 xhr 模块
  action: PropTypes.string,
  // 成功后的回调，参数为服务器返回后的数据
  onSuccess: PropTypes.func,
  // 表单提交回调，参数为当前表单的数据，自定义提交后的行为，不会自动调用save。不指定此属性，表单提交后自动调用save
  onSubmit: PropTypes.func,
  // 提交的数据处理器，参数为当前表单数据，返回最终发送的数据
  sendDataFormatter: PropTypes.func,
  // form表单元素的大小，影响label和值的文字大小
  size: PropTypes.oneOf(['sm', 'lg']),
  customProp: function customProp(_ref3) {
    var data = _ref3.data,
        onChange = _ref3.onChange;

    if (data && !onChange) {
      return new Error('You provided a `data` prop without an `onChange` handler');
    }
  }
};
export default Form;

==> core-react-0.8.2.tgz: package/es/Form/Form/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import update from 'react-update';
import cx from 'classnames';
import invariant from 'invariant';
import xhr from '../../_utils/xhr';


var Form = /*#__PURE__*/function (_React$Component) {
  _inherits(Form, _React$Component);

  function Form(props) {
    var _this;

    _classCallCheck(this, Form);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Form).call(this)); // 存储 FormItem 实例，用于访问 FormItem

    _defineProperty(_assertThisInitialized(_this), "handleSubmit", function () {
      // e.preventDefault()
      _this.props.onSubmit && _this.validate() && _this.props.onSubmit(_this.state.data);
    });

    _this.items = [];
    _this.state = {
      data: props.data || props.defaultData || {},
      isReload: true
    };
    return _this;
  }

  _createClass(Form, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        form: this
      };
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(_ref) {
      var data = _ref.data;
      data && this.setState({
        data: data
      });
    }
    /**
     * 初始化表单数据重新挂载表单内模块
     * @param data
     */

  }, {
    key: "init",
    value: function init(data) {
      this.setState({
        data: data || {},
        isReload: false
      });
      this.setState({
        isReload: true
      });
    }
  }, {
    key: "getItemValue",
    value: function getItemValue(instance, props) {
      var _ref2 = props || instance.props,
          name = _ref2.name,
          multiple = _ref2.multiple;

      var value = this.state.data[name];

      if (!multiple) {
        return value;
      } else {
        if (value instanceof Array) {
          return value[this.multipleMap[instance.uuid]];
        }

        return null;
      }
    }
  }, {
    key: "setItemValue",
    value: function setItemValue(instance, value) {
      var _instance$props = instance.props,
          name = _instance$props.name,
          multiple = _instance$props.multiple;
      var data = this.state.data;
      var nextData;

      if (!multiple) {
        nextData = update(data, 'set', name, value);
      } else {
        if (!data[name]) {
          data[name] = [];
        }

        nextData = update(data, 'set', [name, this.multipleMap[instance.uuid]], value);
      }

      this.setState({
        data: nextData
      });
      this.props.onChange && this.props.onChange(nextData);
    }
  }, {
    key: "addItem",
    value: function addItem(newItem) {
      if (newItem.props.multiple) {
        newItem.uuid = Math.random().toString(16).slice(2);
        this.multipleMap || (this.multipleMap = {});
        this.multipleMap[newItem.uuid] = this.items.filter(function (item) {
          return item.props.name === newItem.props.name;
        }).length;
      }

      this.items.push(newItem);
    }
  }, {
    key: "removeItem",
    value: function removeItem(item) {
      var _this2 = this;

      if (item.props.multiple) {
        delete this.multipleMap[item.uuid]; // Reset index

        var name = item.props.name;
        this.items.filter(function (item) {
          return item.props.name === name;
        }).forEach(function (item, i) {
          _this2.multipleMap[item.uuid] = i;
        });
      }

      this.items.splice(this.items.indexOf(item), 1);
    }
    /**
     * @public
     * @name this.refs.form.validate
     * @param  {object} [data] 验证的数据，默认验证表单当前的数据
     * @return {boolean} 成功/失败
     * @description 表单整体验证
     */

  }, {
    key: "validate",
    value: function validate(data) {
      var _this3 = this;

      data || (data = this.state.data);
      var isValid = true;
      this.items.forEach(function (formItem) {
        var _formItem$props = formItem.props,
            name = _formItem$props.name,
            multiple = _formItem$props.multiple;

        if (!multiple) {
          formItem.validate(data[name]) || (isValid = false);
        } else {
          var index = _this3.multipleMap[formItem.uuid];
          formItem.validate(data[name] && data[name][index]) || (isValid = false);
        }
      });
      return isValid;
    }
    /**
     * @public
     * @name this.refs.form.save
     * @param  {object} [data] 提交的数据，默认提交表单当前的数据
     * @description 表单提交，提交地址为 action 属性, 默认提交 data
     * 属性数据，可以自定义传入。发送请求前会进行表单验证, 提交成功会响应 onSuccess
     */

  }, {
    key: "save",
    value: function save() {
      var _this4 = this;

      var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.state.data;
      var _this$props = this.props,
          action = _this$props.action,
          sendDataFormatter = _this$props.sendDataFormatter,
          onSuccess = _this$props.onSuccess;

      if (this.validate()) {
        invariant(action, 'No `action` provided, check the Form component you save.');
        this.submit && this.submit.toggleProcess(true);
        xhr({
          type: 'POST',
          url: action,
          data: sendDataFormatter ? sendDataFormatter(data) : data,
          success: function success(data) {
            onSuccess && onSuccess(data);
          },
          complete: function complete() {
            _this4.submit && _this4.submit.toggleProcess(false);
          }
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          data = _this$props2.data,
          defaultData = _this$props2.defaultData,
          onChange = _this$props2.onChange,
          onSubmit = _this$props2.onSubmit,
          onSuccess = _this$props2.onSuccess,
          size = _this$props2.size,
          rules = _this$props2.rules,
          labelWidth = _this$props2.labelWidth,
          width = _this$props2.width,
          other = _objectWithoutProperties(_this$props2, ["children", "className", "data", "defaultData", "onChange", "onSubmit", "onSuccess", "size", "rules", "labelWidth", "width"]);

      var classNames = cx("".concat("waui", "-form"), _defineProperty({}, "".concat("waui", "-form_").concat(size), size));

      if (width) {
        other.style = Object.assign(other.style || {}, {
          width: width
        });
      }

      return (/*#__PURE__*/React.createElement("form", _extends({
          onSubmit: this.handleSubmit,
          className: classNames
        }, other), this.state.isReload && children)
      );
    }
  }]);

  return Form;
}(React.Component);

Form.childContextTypes = {
  form: PropTypes.instanceOf(Form)
};
Form.defaultProps = {
  labelWidth: 100
};
Form.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  // 表单数据源，作为表单验证时的数据对象，即 FormInput、FormSelect、FormTextarea 等自动填充的数据源
  data: PropTypes.object,
  // 表单数据源（不可控），同 data
  defaultData: PropTypes.object,
  // 表单数据改变后的回调，参数为当前表单的数据
  onChange: PropTypes.func,
  // 表单验证规则，需要验证的 key 与 data 对象一一对应
  rules: PropTypes.object,
  // 表单的宽度大小，单位为px
  width: PropTypes.number,
  // 表单 label 宽度，如果不需要 label，设置为`0`即可
  labelWidth: PropTypes.number,
  // 表单提交 URL，内部调用 xhr 模块
  action: PropTypes.string,
  // 成功后的回调，参数为服务器返回后的数据
  onSuccess: PropTypes.func,
  // 表单提交回调，参数为当前表单的数据，自定义提交后的行为，不会自动调用save。不指定此属性，表单提交后自动调用save
  onSubmit: PropTypes.func,
  // 提交的数据处理器，参数为当前表单数据，返回最终发送的数据
  sendDataFormatter: PropTypes.func,
  // form表单元素的大小，影响label和值的文字大小
  size: PropTypes.oneOf(['sm', 'lg']),
  customProp: function customProp(_ref3) {
    var data = _ref3.data,
        onChange = _ref3.onChange;

    if (data && !onChange) {
      return new Error('You provided a `data` prop without an `onChange` handler');
    }
  }
};
export default Form;
